clear all; close all; clc;

%% Load input data

% NASA image - optimal params ==> patch size = 151, reg_param = 0.1
load AVIRIS;
HR_image = data_HR_reg(:,:,[27 18 9]);


%% Generate LR image

% %%%%%%%%%%%%%%%%%%%% Method 1 for generating LR image %%%%%%%%%%%%%%%%%%%%%
% %Smaller patch size = better results
% LR_image = imresize(imresize(oct_s331(:,:,[5 15 54]),1/3),3); % Create LR HS image to the size of the HR MS image;
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%% Method 2 for generating LR image %%%%%%%%%%%%%%%%%%%%%
% Larger patch size = better results
% The following lines emulate a blurred version of the LR HS image
scale = 3;
size_kernel=[5 5];
sig = (1/(2*(2.7725887)/scale^2))^0.5;
start_pos(1)=1; % The starting point of downsampling
start_pos(2)=1; % The starting point of downsampling
[LR_image_blurred,KerBlu]=conv_downsample(HR_image,scale,size_kernel,sig,start_pos);
LR_image = imresize(LR_image_blurred,[size(HR_image,1) size(HR_image,2)]);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Run HCM
patch_size = 9;
reg_param = 0.1;
nx = HCM(HR_image,LR_image,[],patch_size,reg_param); % Fusion program; nx is the HR HS image % cube; it can be compared with oct_s331 to generate performance
[rmse, ~] = RMSE(HR_image/max(HR_image(:)),nx/max(nx(:)));

%% Display images
figure,imshow(HR_image/max(HR_image(:)));title('HR image');
figure,imshow(LR_image/max(LR_image(:))); title('LR image');
figure,imshow(nx/max(nx(:))); title(['Output image with RMSE = ' num2str(rmse)]);